﻿;LM (Win64)
;Version: 4.0
;Autor: Adrian Kurz - adkurz@bltech.de
;Funktionen:
;Steuert mittels Tastenkürzeln die Lautstärke einzelner Programme, welche sich im Fokus befinden. Zudem können diese Programme Stummgeschaltet werden. Diese Funktionen sind durch andere Tastenkürzel auch auf die Gesamtlautstärke anwendbar.
;Erstellt: 2019-01-04

;Anfangskonstanten und Variablen
#NoEnv
#Persistent
#include ..\lib\va.ahk
global LMVersion := 4.0

;Erstellung des Traymenüs
Menu, Tray, NoStandard
Menu, Tray, Add, LM &pausieren oder Fortsetzen, LM_Pause
Menu, Tray, Add, LM &Konfigurieren, LM_OpenConfig
Menu, Tray, Add, &Anleitung öffnen, LM_Help
Menu, Tray, Add, &Beenden, LM_Exit
Menu, Tray, Default, LM &pausieren oder Fortsetzen

;Aufrufen der Konfigurations-Subrutine
LM_UpdateConfig()

;Startsound abspielen
LM_Startsound()
;Definition der Tastenkürzel, gelesen aus LM.ini
HotKey, % config("ProgrammLeiser", "LM-Hotkeys", "^+!F1"), LM_ProgrammLeiser
HotKey, % config("ProgrammLauter", "LM-Hotkeys", "^+!F2"), LM_ProgrammLauter
HotKey, % config("SystemLeiser", "LM-Hotkeys", "^+!F3"), LM_SystemLeiser
HotKey, % config("SystemLauter", "LM-Hotkeys", "^+!F4"), LM_SystemLauter
HotKey, % config("ProgrammStummschalten", "LM-Hotkeys", "^+!F5"), LM_ProgrammStummschalten
HotKey, % config("SystemStummschalten", "LM-Hotkeys", "^+!F6"), LM_SystemStummschalten
HotKey, % config("SystemsoundsLeiser", "LM-Hotkeys", "^+!F7"), LM_SystemsoundsLeiser
HotKey, % config("SystemsoundsLauter", "LM-Hotkeys", "^+!F8"), LM_SystemsoundsLauter
HotKey, % config("MikrofonLeiser", "LM-Hotkeys", "^+!F9"), LM_MikrofonLeiser
HotKey, % config("MikrofonLauter", "LM-Hotkeys", "^+!F10"), LM_MikrofonLauter
HotKey, % config("MikrofonUmschalten", "LM-Hotkeys", "^+!F11"), LM_MikrofonUmschalten
HotKey, % config("LMPausieren", "LM-Hotkeys", "#^+p"), LM_Pause
HotKey, % config("LMAnleitungÖffnen", "LM-Hotkeys", "#^+F1"), LM_Help
HotKey, % config("LMBeenden", "LM-Hotkeys", "#^+e"), LM_Exit
Return

;Funktion: Konfiguration von LM überprüfen
LM_UpdateConfig() {
  if !FileExist("..\LM.ini") {
    MsgBox, 4160, Willkommen zu LM, Willkommen zu LM %LMVersion% von Adrian Kurz. Anscheinend starten Sie LM zum Ersten mal. Nach Bestätigung dieser Meldung wird die Konfigurationsdatei LM.ini erstellt, in welcher Sie die Tastenkürzel von LM ändern können. Weitere Informationen sind in der LM-Anleitung zu finden, welche über das Infobereichsymbol von LM aufgerufen werden kann.
    FileAppend,
(
;Konfigurationsdatei für LM
[LM-Hotkeys]
[LM-Info]
)
, ..\LM.ini, UTF-16
IniWrite, %LMVersion%, ..\lm.ini, LM-Info, LMVersion
    if FileExist("..\LM.ini") {
      MsgBox, 4160, Konfiguration Erfolgreich, Die Konfiguration wurde erfolgreich erstellt. Viel Spaß mit LM!
    } else {
      MsgBox, 4112, Konfigurationsfehler, Es ist ein Fehler aufgetreten. Stellen Sie sicher, dass sich die Programmdateien in einem Ordner mit ausreichenden Schreibberechtigungen befinden. Bei weiteren Problemen wenden Sie sich bitte an info@bltech.de.
      ExitApp  
    }
  }

  IniRead, iniVersion, ..\LM.ini, LM-Info, LMVersion
  IniDelete, ..\lm.ini, LM-Hotkeys, MikrofonAusschalten
  IniDelete, ..\lm.ini, LM-Hotkeys, MikrofonEinschalten

  if (iniVersion != LMVersion) {
    MsgBox, 4132, LM wurde aktuallisiert, Sie haben LM von Version %iniVersion% auf Version %LMVersion% aktuallisiert. Viel Vergnügen mit der neuen Version!`r`nMöchten Sie die Datei mit den Neuerungen aufrufen?
    IfMsgBox, Yes
    Run, ..\Neuerungen.txt

    IniWrite, %LMVersion%, ..\lm.ini, LM-Info, LMVersion
  }
}

;Subrutinen: Lautstärkeaktionen:
LM_ProgrammLeiser:
    Run, nircmd\nircmd.exe changeappvolume focused -0.025
Return

LM_ProgrammLauter:
  Run, nircmd\nircmd.exe changeappvolume focused 0.025
Return

LM_SystemLeiser:
  Run, nircmd\nircmd.exe changesysvolume -1638.375
  Soundplay, ..\Sounds\Ding.wav
return

LM_SystemLauter:
  Run, nircmd\nircmd.exe changesysvolume 1638.375
  Soundplay, ..\Sounds\Ding.wav
return

LM_ProgrammStummschalten:
  Run, nircmd\nircmd.exe muteappvolume focused 2
Return

LM_SystemStummschalten:
  Run, nircmd\nircmd.exe mutesysvolume 2
Return

LM_SystemsoundsLeiser:
  Run nircmd\nircmd.exe changeappvolume systemsounds -0.025
  Soundplay, *-1
Return

LM_SystemsoundsLauter:
  Run nircmd\nircmd.exe changeappvolume systemsounds 0.025
  Soundplay, *-1
return

;Subrutine: Mikrofonlautstärke verringern
LM_MikrofonLeiser:
oldVolumeDown := VA_GetMasterVolume("", "capture")
if (oldVolumeDown > 0) {
newVolumeDown := oldVolumeDown -1
VA_SetMasterVolume(newVolumeDown, "", "capture")
SoundBeep, % 110 * 2 ** (newVolumeDown / 25.0), 40
}
Return

;Subrutine: Mikrofonlautstärke erhöhen
LM_MikrofonLauter:
oldVolumeUp := VA_GetMasterVolume("", "capture")
if (oldvolumeUp < 100) {
newVolumeUp := oldVolumeUp +1
VA_SetMasterVolume(newVolumeUp, "", "capture")
SoundBeep, % 110 * 2 ** (newVolumeUp / 25.0), 40
}
Return

;Subrutine: Mikrofon umschalten
LM_MikrofonUmschalten:
if (VA_GetMasterMute("capture") == 0) {
VA_SetMasterMute(true, "capture")
SoundPlay, ..\Sounds\Mikrofon_Aus.wav
} else {
VA_SetMasterMute(false, "capture")
SoundPlay, ..\Sounds\Mikrofon_Ein.wav
}
Return

;Subrutine: LM Pausieren
LM_Pause:
  Suspend
  if (A_IsSuspended = 1) {
    Soundplay, ..\Sounds\LM_Aus.wav
  } else {
    Soundplay, ..\Sounds\LM_Ein.wav
  }
return

;Subrutine: LM.ini öffnen und nach Konfiguration neustarten
LM_OpenConfig:
Runwait, notepad.exe ..\LM.ini
reload
Return

;Subrutine: Anleitung von LM öffnen
LM_Help:
  Run, ..\Anleitung.html
return

;Funktion: LM-Startsound abspielen:
LM_Startsound() {
  Soundplay, ..\Sounds\LM_Aus.wav
  Sleep 200
  Soundplay, ..\Sounds\LM_Ein.wav
}

;Subrutine: LM Beenden
LM_Exit:
  Soundplay, ..\Sounds\LM_Ein.wav
  Sleep 200
  Soundplay, ..\Sounds\LM_Aus.wav
  sleep 900
  ExitApp
return

config(setting, section, standard) {
  IniRead, check, ..\LM.ini, %section%, %setting%
  if (check == "ERROR") {
    IniWrite, %standard%, ..\lm.ini, %section%, %setting%
    IniRead, value, ..\LM.ini, %section%, %setting%
  } else {
    IniRead, value, ..\LM.ini, %section%, %setting%
  }
  Return value
}